@@ -496,7 +496,7 @@ class SubmitClient:
       if "EDITOR_CHOICE" in environmentVars:
          environmentVars.remove("EDITOR_CHOICE")
       if len(environmentVars) > 0:
-         useEnvironment = ". /apps/environ/.setup.sh\n"
+         useEnvironment = ". /etc/environ.sh\n"
          if "ENVIRON_CONFIG_DIRS" in os.environ:
             useEnvironment += "export ENVIRON_CONFIG_DIRS=\"" + os.environ['ENVIRON_CONFIG_DIRS'] + "\"\n"
          for environmentVar in environmentVars:
